@@ -96,7 +96,7 @@ class SecurityService:
         return f'SHA-256={self.calculate_digest(msg).decode("ascii")}'
 
     def generate_headers(self, url, method='get', request=None):
-        uri = '/' + '/'.join(url.split('/')[3::]).split('?')[0]
+        uri = '/' + '/'.join(url.split('/')[3::])
         request_line = f'{method.upper()} {uri} HTTP/1.1'
         x_date = self.httpdate()
         digest = self.create_digest(json.dumps(request).encode() if request else b'')
@@ -107,7 +107,7 @@ class SecurityService:
                         f'headers="digest x-date request-line", signature="{b64encode(signature).decode()}" '
 
         return {'digest': digest, 'x-date': x_date, 'authorization': str(authorization),
-                'user-agent': 'coin-sdk-python-1.4.0'}
+                'user-agent': 'coin-sdk-python-1.6.8'}
 
     def generate_jwt(self):
         return {'jwt': f'{self.get_token()}'}
