@@ -8,9 +8,10 @@ import sseclient
 from requests import ConnectionError
 from requests.exceptions import ChunkedEncodingError, ReadTimeout
 
+from coin_sdk.common.sendrequest import json2obj
 from coin_sdk.number_portability.domain import MessageType, ConfirmationStatus
 from coin_sdk.common.securityservice import SecurityService
-from coin_sdk.number_portability.utils import json2obj, handle_http_error, get_stream
+from coin_sdk.number_portability.utils import get_stream, NumberPortabilityErrorHandler
 from coin_sdk.number_portability.npconfig import NpConfig
 
 logger = logging.getLogger(__name__)
@@ -56,6 +57,7 @@ class Receiver(ABC):
         self._offset_persister: Optional[OffsetPersister] = None
         self._recover_offset: Callable[[int], int] = lambda x: x
         self._running = None
+        self._error_handler = NumberPortabilityErrorHandler()
         self._event_map = {
             MessageType.PORTING_REQUEST_V3.get_event_type(): self.on_porting_request,
             MessageType.PORTING_REQUEST_ANSWER_V3.get_event_type(): self.on_porting_request_answer,
@@ -123,7 +125,7 @@ class Receiver(ABC):
         logger.debug('Opening stream')
         response = get_stream(self._config.sse_url, offset, confirmation_status, message_types, self._security_service)
         logger.debug(f'url: {response.request.url}')
-        handle_http_error(response)
+        self._error_handler.handle_http_error(response)
         client = sseclient.SSEClient(response)
         retries_left.reset()
         self._consume_stream(client)
